/*
 * Copyright (c) 2024, NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 */

#ifndef SYSCALL_TRACE_H
#define SYSCALL_TRACE_H

struct syscall_trace_data {
    __u64 timestamp_start;
    __u64 timestamp_end;
    __u64 syscall_nr;
    __u32 tgid;
    __u32 pid;
    __u16 seq_nr;
    __u16 ustack_byte_size;

    /*
     * Buffer for storing user space backtrace which leads to the system call.
     * Implemented as a flexible array field (see [1] for details) to make
     * the buffer size configurable, as it directly affects memory consumption.
     *
     * [1] https://www.gnu.org/software/c-intro-and-ref/manual/html_node/Flexible-Array-Fields.html
     */
    __u64 ustack[];
};

#endif /* SYSCALL_TRACE_H */
